==> igniteui-webcomponents-core-4.0.2.tgz: package/esm5/lib/CheckedChangedEventArgsDescription.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import * as tslib_1 from "tslib";
import { Description } from "./Description";
import { markType } from "./type";
/**
 * @hidden
 */
var CheckedChangedEventArgsDescription = /** @class */ /*@__PURE__*/ (function (_super) {
    tslib_1.__extends(CheckedChangedEventArgsDescription, _super);
    function CheckedChangedEventArgsDescription() {
        var _this = _super.call(this) || this;
        _this.h = 0;
        _this.f = false;
        return _this;
    }
    CheckedChangedEventArgsDescription.prototype.get_type = function () {
        return "CheckedChangedEventArgs";
    };
    Object.defineProperty(CheckedChangedEventArgsDescription.prototype, "type", {
        get: function () {
            return this.get_type();
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(CheckedChangedEventArgsDescription.prototype, "index", {
        get: function () {
            return this.h;
        },
        set: function (a) {
            this.h = a;
            this.e("Index");
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(CheckedChangedEventArgsDescription.prototype, "isChecked", {
        get: function () {
            return this.f;
        },
        set: function (a) {
            this.f = a;
            this.e("IsChecked");
        },
        enumerable: true,
        configurable: true
    });
    CheckedChangedEventArgsDescription.$t = markType(CheckedChangedEventArgsDescription, 'CheckedChangedEventArgsDescription', Description.$);
    return CheckedChangedEventArgsDescription;
}(Description));
export { CheckedChangedEventArgsDescription };

==> igniteui-webcomponents-core-5.4.1.tgz: package/esm5/lib/CheckedChangedEventArgsDescription.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Description } from "./Description";
import { markType } from "./type";
/**
 * @hidden
 */
var CheckedChangedEventArgsDescription = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(CheckedChangedEventArgsDescription, _super);
    function CheckedChangedEventArgsDescription() {
        var _this = _super.call(this) || this;
        _this.j = 0;
        _this.h = false;
        _this.l = null;
        return _this;
    }
    CheckedChangedEventArgsDescription.prototype.get_type = function () {
        return "CheckedChangedEventArgs";
    };
    Object.defineProperty(CheckedChangedEventArgsDescription.prototype, "type", {
        get: function () {
            return this.get_type();
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(CheckedChangedEventArgsDescription.prototype, "index", {
        get: function () {
            return this.j;
        },
        set: function (a) {
            this.j = a;
            this.g("Index");
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(CheckedChangedEventArgsDescription.prototype, "isChecked", {
        get: function () {
            return this.h;
        },
        set: function (a) {
            this.h = a;
            this.g("IsChecked");
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(CheckedChangedEventArgsDescription.prototype, "primaryKeyRef", {
        get: function () {
            return this.l;
        },
        set: function (a) {
            this.l = a;
            this.g("PrimaryKeyRef");
        },
        enumerable: false,
        configurable: true
    });
    CheckedChangedEventArgsDescription.$t = markType(CheckedChangedEventArgsDescription, 'CheckedChangedEventArgsDescription', Description.$);
    return CheckedChangedEventArgsDescription;
}(Description));
export { CheckedChangedEventArgsDescription };
